@@ -9,8 +9,8 @@ class AnythingTest < Test::Unit::TestCase
   
   def test_should_match_anything
     matcher = anything
-    assert matcher == :something
-    assert matcher == {'x' => 'y'}
+    assert matcher.matches?([:something])
+    assert matcher.matches?([{'x' => 'y'}])
   end
   
   def test_should_describe_matcher
